@@ -6,6 +6,15 @@ import pandas as pd
 
 from .utils import Date
 
+"""
+Sistema Gerenciador de Séries Temporais (SGS)
+
+O módulo ``sgs`` obtem os dados do webservice do Banco Central,
+interface json do serviço BCData/SGS -
+`Sistema Gerenciador de Séries Temporais (SGS)
+<https://www3.bcb.gov.br/sgspub/localizarseries/localizarSeries.do?method=prepararTelaLocalizarSeries>`_.
+"""
+
 
 class SGSCode:
     def __init__(self, code, name=None):
