@@ -1,12 +1,11 @@
-
 from datetime import datetime, date
 
 
 class Date:
-    def __init__(self, d=None, format='%Y-%m-%d', mindate=date(1900, 1, 1)):
+    def __init__(self, d=None, format="%Y-%m-%d", mindate=date(1900, 1, 1)):
         d = d if d else mindate
         if isinstance(d, str):
-            if d == 'now' or d == 'today':
+            if d == "now" or d == "today":
                 d = date.today()
             else:
                 d = datetime.strptime(d, format).date()
@@ -20,7 +19,7 @@ class Date:
             raise ValueError()
         self.date = d
 
-    def format(self, fmts='%Y-%m-%d'):
+    def format(self, fmts="%Y-%m-%d"):
         return datetime.strftime(self.date, fmts)
 
     def __gt__(self, other):
